@@ -4,5 +4,5 @@
 The __init__.py files are required to make Python treat directories
 containing the file as packages.
 """
-from gold_python.deterministic import DeterministicAutomata, DeterministicTrasducer
-from gold_python.delta import deltafunc, transducerfunc, pushdownfunc
+from gold_python.automata import *
+from gold_python.delta import *
